betty.project.extension.gramps package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.gramps package

## Submodules

- betty.project.extension.gramps.config module
  - `FamilyTreeConfiguration`
    - `FamilyTreeConfiguration.__init__()`
    - `FamilyTreeConfiguration.dump()`
    - `FamilyTreeConfiguration.event_types`
    - `FamilyTreeConfiguration.file_path`
    - `FamilyTreeConfiguration.genders`
    - `FamilyTreeConfiguration.load()`
    - `FamilyTreeConfiguration.place_types`
    - `FamilyTreeConfiguration.presence_roles`
  - `FamilyTreeConfigurationSequence`
  - `GrampsConfiguration`
    - `GrampsConfiguration.__init__()`
    - `GrampsConfiguration.dump()`
    - `GrampsConfiguration.family_trees`
    - `GrampsConfiguration.load()`
  - `PluginMapping`
    - `PluginMapping.__init__()`
    - `PluginMapping.dump()`
    - `PluginMapping.load()`

## Module contents

Integrate Betty with Gramps.

final class betty.project.extension.gramps.Gramps

  Bases: `ShorthandPluginBase`, `ConfigurableExtension`[`GrampsConfiguration`]

  Integrate Betty with Gramps.

  classmethod new_default_configuration() → GrampsConfiguration

    Create this extension’s default configuration.

  register_event_handlers(registry: EventHandlerRegistry) → None

    Register event handlers with the project.